"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BackupMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class FrankingMetadata(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            FRANKINGTAG_FIELD_NUMBER: builtins.int
            REPORTINGTAG_FIELD_NUMBER: builtins.int
            frankingTag: builtins.bytes
            reportingTag: builtins.bytes
            def __init__(
                self,
                *,
                frankingTag: builtins.bytes | None = ...,
                reportingTag: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing.Literal[
                    "frankingTag", b"frankingTag", "reportingTag", b"reportingTag"
                ],
            ) -> builtins.bool: ...
            def ClearField(
                self,
                field_name: typing.Literal[
                    "frankingTag", b"frankingTag", "reportingTag", b"reportingTag"
                ],
            ) -> None: ...

        SENDERID_FIELD_NUMBER: builtins.int
        MESSAGEID_FIELD_NUMBER: builtins.int
        TIMESTAMPMS_FIELD_NUMBER: builtins.int
        FRANKINGMETADATA_FIELD_NUMBER: builtins.int
        PAYLOADVERSION_FIELD_NUMBER: builtins.int
        FUTUREPROOFBEHAVIOR_FIELD_NUMBER: builtins.int
        senderID: builtins.str
        messageID: builtins.str
        timestampMS: builtins.int
        payloadVersion: builtins.int
        futureProofBehavior: builtins.int
        @property
        def frankingMetadata(
            self,
        ) -> global___BackupMessage.Metadata.FrankingMetadata: ...
        def __init__(
            self,
            *,
            senderID: builtins.str | None = ...,
            messageID: builtins.str | None = ...,
            timestampMS: builtins.int | None = ...,
            frankingMetadata: global___BackupMessage.Metadata.FrankingMetadata
            | None = ...,
            payloadVersion: builtins.int | None = ...,
            futureProofBehavior: builtins.int | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "frankingMetadata",
                b"frankingMetadata",
                "futureProofBehavior",
                b"futureProofBehavior",
                "messageID",
                b"messageID",
                "payloadVersion",
                b"payloadVersion",
                "senderID",
                b"senderID",
                "timestampMS",
                b"timestampMS",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "frankingMetadata",
                b"frankingMetadata",
                "futureProofBehavior",
                b"futureProofBehavior",
                "messageID",
                b"messageID",
                "payloadVersion",
                b"payloadVersion",
                "senderID",
                b"senderID",
                "timestampMS",
                b"timestampMS",
            ],
        ) -> None: ...

    METADATA_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    payload: builtins.bytes
    @property
    def metadata(self) -> global___BackupMessage.Metadata: ...
    def __init__(
        self,
        *,
        metadata: global___BackupMessage.Metadata | None = ...,
        payload: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]
    ) -> None: ...

global___BackupMessage = BackupMessage



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExtendedContentMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _OverlayIconGlyph:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OverlayIconGlyphEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtendedContentMessage._OverlayIconGlyph.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INFO: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 0
        EYE_OFF: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 1
        NEWS_OFF: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 2
        WARNING: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 3
        PRIVATE: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 4
        NONE: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 5
        MEDIA_LABEL: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 6
        POST_COVER: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 7
        POST_LABEL: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 8
        WARNING_SCREENS: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 9

    class OverlayIconGlyph(
        _OverlayIconGlyph, metaclass=_OverlayIconGlyphEnumTypeWrapper
    ): ...
    INFO: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 0
    EYE_OFF: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 1
    NEWS_OFF: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 2
    WARNING: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 3
    PRIVATE: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 4
    NONE: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 5
    MEDIA_LABEL: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 6
    POST_COVER: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 7
    POST_LABEL: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 8
    WARNING_SCREENS: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 9

    class _CtaButtonType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CtaButtonTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtendedContentMessage._CtaButtonType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OPEN_NATIVE: ExtendedContentMessage._CtaButtonType.ValueType  # 11

    class CtaButtonType(_CtaButtonType, metaclass=_CtaButtonTypeEnumTypeWrapper): ...
    OPEN_NATIVE: ExtendedContentMessage.CtaButtonType.ValueType  # 11

    class _XmaLayoutType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmaLayoutTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtendedContentMessage._XmaLayoutType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SINGLE: ExtendedContentMessage._XmaLayoutType.ValueType  # 0
        HSCROLL: ExtendedContentMessage._XmaLayoutType.ValueType  # 1
        PORTRAIT: ExtendedContentMessage._XmaLayoutType.ValueType  # 3
        STANDARD_DXMA: ExtendedContentMessage._XmaLayoutType.ValueType  # 12
        LIST_DXMA: ExtendedContentMessage._XmaLayoutType.ValueType  # 15
        GRID: ExtendedContentMessage._XmaLayoutType.ValueType  # 16

    class XmaLayoutType(_XmaLayoutType, metaclass=_XmaLayoutTypeEnumTypeWrapper): ...
    SINGLE: ExtendedContentMessage.XmaLayoutType.ValueType  # 0
    HSCROLL: ExtendedContentMessage.XmaLayoutType.ValueType  # 1
    PORTRAIT: ExtendedContentMessage.XmaLayoutType.ValueType  # 3
    STANDARD_DXMA: ExtendedContentMessage.XmaLayoutType.ValueType  # 12
    LIST_DXMA: ExtendedContentMessage.XmaLayoutType.ValueType  # 15
    GRID: ExtendedContentMessage.XmaLayoutType.ValueType  # 16

    class _ExtendedContentType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ExtendedContentTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtendedContentMessage._ExtendedContentType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNSUPPORTED: ExtendedContentMessage._ExtendedContentType.ValueType  # 0
        IG_STORY_PHOTO_MENTION: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 4
        IG_SINGLE_IMAGE_POST_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 9
        IG_MULTIPOST_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 10
        IG_SINGLE_VIDEO_POST_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 11
        IG_STORY_PHOTO_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 12
        IG_STORY_VIDEO_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 13
        IG_CLIPS_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 14
        IG_IGTV_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 15
        IG_SHOP_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 16
        IG_PROFILE_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 19
        IG_STORY_PHOTO_HIGHLIGHT_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 20
        IG_STORY_VIDEO_HIGHLIGHT_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 21
        IG_STORY_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 22
        IG_STORY_REACTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 23
        IG_STORY_VIDEO_MENTION: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 24
        IG_STORY_HIGHLIGHT_REPLY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 25
        IG_STORY_HIGHLIGHT_REACTION: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 26
        IG_EXTERNAL_LINK: ExtendedContentMessage._ExtendedContentType.ValueType  # 27
        IG_RECEIVER_FETCH: ExtendedContentMessage._ExtendedContentType.ValueType  # 28
        FB_FEED_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1000
        FB_STORY_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 1001
        FB_STORY_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1002
        FB_STORY_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 1003
        FB_FEED_VIDEO_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 1004
        FB_GAMING_CUSTOM_UPDATE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 1005
        FB_PRODUCER_STORY_REPLY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 1006
        FB_EVENT: ExtendedContentMessage._ExtendedContentType.ValueType  # 1007
        FB_FEED_POST_PRIVATE_REPLY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 1008
        FB_SHORT: ExtendedContentMessage._ExtendedContentType.ValueType  # 1009
        FB_COMMENT_MENTION_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 1010
        MSG_EXTERNAL_LINK_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2000
        MSG_P2P_PAYMENT: ExtendedContentMessage._ExtendedContentType.ValueType  # 2001
        MSG_LOCATION_SHARING: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2002
        MSG_LOCATION_SHARING_V2: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2003
        MSG_HIGHLIGHTS_TAB_FRIEND_UPDATES_REPLY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2004
        MSG_HIGHLIGHTS_TAB_LOCAL_EVENT_REPLY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2005
        MSG_RECEIVER_FETCH: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2006
        MSG_IG_MEDIA_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2007
        MSG_GEN_AI_SEARCH_PLUGIN_RESPONSE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2008
        MSG_REELS_LIST: ExtendedContentMessage._ExtendedContentType.ValueType  # 2009
        MSG_CONTACT: ExtendedContentMessage._ExtendedContentType.ValueType  # 2010
        MSG_THREADS_POST_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2011
        MSG_FILE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2012
        MSG_AVATAR_DETAILS: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2013
        MSG_AI_CONTACT: ExtendedContentMessage._ExtendedContentType.ValueType  # 2014
        MSG_MEMORIES_SHARE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2015
        MSG_SHARED_ALBUM_REPLY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2016
        MSG_SHARED_ALBUM: ExtendedContentMessage._ExtendedContentType.ValueType  # 2017
        MSG_OCCAMADILLO_XMA: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2018
        MSG_GEN_AI_SUBSCRIPTION: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2021
        MSG_GEN_AI_REMINDER: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2022
        MSG_GEN_AI_MEMU_ONBOARDING_RESPONSE: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 2023
        MSG_NOTE_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 2024
        MSG_NOTE_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 2025
        RTC_AUDIO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3000
        RTC_VIDEO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3001
        RTC_MISSED_AUDIO_CALL: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 3002
        RTC_MISSED_VIDEO_CALL: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 3003
        RTC_GROUP_AUDIO_CALL: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 3004
        RTC_GROUP_VIDEO_CALL: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 3005
        RTC_MISSED_GROUP_AUDIO_CALL: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 3006
        RTC_MISSED_GROUP_VIDEO_CALL: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 3007
        DATACLASS_SENDER_COPY: (
            ExtendedContentMessage._ExtendedContentType.ValueType
        )  # 4000

    class ExtendedContentType(
        _ExtendedContentType, metaclass=_ExtendedContentTypeEnumTypeWrapper
    ): ...
    UNSUPPORTED: ExtendedContentMessage.ExtendedContentType.ValueType  # 0
    IG_STORY_PHOTO_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 4
    IG_SINGLE_IMAGE_POST_SHARE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 9
    IG_MULTIPOST_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 10
    IG_SINGLE_VIDEO_POST_SHARE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 11
    IG_STORY_PHOTO_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 12
    IG_STORY_VIDEO_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 13
    IG_CLIPS_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 14
    IG_IGTV_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 15
    IG_SHOP_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 16
    IG_PROFILE_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 19
    IG_STORY_PHOTO_HIGHLIGHT_SHARE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 20
    IG_STORY_VIDEO_HIGHLIGHT_SHARE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 21
    IG_STORY_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 22
    IG_STORY_REACTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 23
    IG_STORY_VIDEO_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 24
    IG_STORY_HIGHLIGHT_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 25
    IG_STORY_HIGHLIGHT_REACTION: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 26
    IG_EXTERNAL_LINK: ExtendedContentMessage.ExtendedContentType.ValueType  # 27
    IG_RECEIVER_FETCH: ExtendedContentMessage.ExtendedContentType.ValueType  # 28
    FB_FEED_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1000
    FB_STORY_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 1001
    FB_STORY_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1002
    FB_STORY_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 1003
    FB_FEED_VIDEO_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1004
    FB_GAMING_CUSTOM_UPDATE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 1005
    FB_PRODUCER_STORY_REPLY: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 1006
    FB_EVENT: ExtendedContentMessage.ExtendedContentType.ValueType  # 1007
    FB_FEED_POST_PRIVATE_REPLY: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 1008
    FB_SHORT: ExtendedContentMessage.ExtendedContentType.ValueType  # 1009
    FB_COMMENT_MENTION_SHARE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 1010
    MSG_EXTERNAL_LINK_SHARE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2000
    MSG_P2P_PAYMENT: ExtendedContentMessage.ExtendedContentType.ValueType  # 2001
    MSG_LOCATION_SHARING: ExtendedContentMessage.ExtendedContentType.ValueType  # 2002
    MSG_LOCATION_SHARING_V2: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2003
    MSG_HIGHLIGHTS_TAB_FRIEND_UPDATES_REPLY: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2004
    MSG_HIGHLIGHTS_TAB_LOCAL_EVENT_REPLY: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2005
    MSG_RECEIVER_FETCH: ExtendedContentMessage.ExtendedContentType.ValueType  # 2006
    MSG_IG_MEDIA_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2007
    MSG_GEN_AI_SEARCH_PLUGIN_RESPONSE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2008
    MSG_REELS_LIST: ExtendedContentMessage.ExtendedContentType.ValueType  # 2009
    MSG_CONTACT: ExtendedContentMessage.ExtendedContentType.ValueType  # 2010
    MSG_THREADS_POST_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2011
    MSG_FILE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2012
    MSG_AVATAR_DETAILS: ExtendedContentMessage.ExtendedContentType.ValueType  # 2013
    MSG_AI_CONTACT: ExtendedContentMessage.ExtendedContentType.ValueType  # 2014
    MSG_MEMORIES_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2015
    MSG_SHARED_ALBUM_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 2016
    MSG_SHARED_ALBUM: ExtendedContentMessage.ExtendedContentType.ValueType  # 2017
    MSG_OCCAMADILLO_XMA: ExtendedContentMessage.ExtendedContentType.ValueType  # 2018
    MSG_GEN_AI_SUBSCRIPTION: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2021
    MSG_GEN_AI_REMINDER: ExtendedContentMessage.ExtendedContentType.ValueType  # 2022
    MSG_GEN_AI_MEMU_ONBOARDING_RESPONSE: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 2023
    MSG_NOTE_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 2024
    MSG_NOTE_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 2025
    RTC_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3000
    RTC_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3001
    RTC_MISSED_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3002
    RTC_MISSED_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3003
    RTC_GROUP_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3004
    RTC_GROUP_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3005
    RTC_MISSED_GROUP_AUDIO_CALL: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 3006
    RTC_MISSED_GROUP_VIDEO_CALL: (
        ExtendedContentMessage.ExtendedContentType.ValueType
    )  # 3007
    DATACLASS_SENDER_COPY: ExtendedContentMessage.ExtendedContentType.ValueType  # 4000

    @typing.final
    class CTA(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BUTTONTYPE_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        ACTIONURL_FIELD_NUMBER: builtins.int
        NATIVEURL_FIELD_NUMBER: builtins.int
        CTATYPE_FIELD_NUMBER: builtins.int
        ACTIONCONTENTBLOB_FIELD_NUMBER: builtins.int
        buttonType: global___ExtendedContentMessage.CtaButtonType.ValueType
        title: builtins.str
        actionURL: builtins.str
        nativeURL: builtins.str
        ctaType: builtins.str
        actionContentBlob: builtins.str
        def __init__(
            self,
            *,
            buttonType: global___ExtendedContentMessage.CtaButtonType.ValueType
            | None = ...,
            title: builtins.str | None = ...,
            actionURL: builtins.str | None = ...,
            nativeURL: builtins.str | None = ...,
            ctaType: builtins.str | None = ...,
            actionContentBlob: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "actionContentBlob",
                b"actionContentBlob",
                "actionURL",
                b"actionURL",
                "buttonType",
                b"buttonType",
                "ctaType",
                b"ctaType",
                "nativeURL",
                b"nativeURL",
                "title",
                b"title",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "actionContentBlob",
                b"actionContentBlob",
                "actionURL",
                b"actionURL",
                "buttonType",
                b"buttonType",
                "ctaType",
                b"ctaType",
                "nativeURL",
                b"nativeURL",
                "title",
                b"title",
            ],
        ) -> None: ...

    ASSOCIATEDMESSAGE_FIELD_NUMBER: builtins.int
    TARGETTYPE_FIELD_NUMBER: builtins.int
    TARGETUSERNAME_FIELD_NUMBER: builtins.int
    TARGETID_FIELD_NUMBER: builtins.int
    TARGETEXPIRINGATSEC_FIELD_NUMBER: builtins.int
    XMALAYOUTTYPE_FIELD_NUMBER: builtins.int
    CTAS_FIELD_NUMBER: builtins.int
    PREVIEWS_FIELD_NUMBER: builtins.int
    TITLETEXT_FIELD_NUMBER: builtins.int
    SUBTITLETEXT_FIELD_NUMBER: builtins.int
    MAXTITLENUMOFLINES_FIELD_NUMBER: builtins.int
    MAXSUBTITLENUMOFLINES_FIELD_NUMBER: builtins.int
    FAVICON_FIELD_NUMBER: builtins.int
    HEADERIMAGE_FIELD_NUMBER: builtins.int
    HEADERTITLE_FIELD_NUMBER: builtins.int
    OVERLAYICONGLYPH_FIELD_NUMBER: builtins.int
    OVERLAYTITLE_FIELD_NUMBER: builtins.int
    OVERLAYDESCRIPTION_FIELD_NUMBER: builtins.int
    SENTWITHMESSAGEID_FIELD_NUMBER: builtins.int
    MESSAGETEXT_FIELD_NUMBER: builtins.int
    HEADERSUBTITLE_FIELD_NUMBER: builtins.int
    XMADATACLASS_FIELD_NUMBER: builtins.int
    CONTENTREF_FIELD_NUMBER: builtins.int
    MENTIONEDJID_FIELD_NUMBER: builtins.int
    COMMANDS_FIELD_NUMBER: builtins.int
    targetType: global___ExtendedContentMessage.ExtendedContentType.ValueType
    targetUsername: builtins.str
    targetID: builtins.str
    targetExpiringAtSec: builtins.int
    xmaLayoutType: global___ExtendedContentMessage.XmaLayoutType.ValueType
    titleText: builtins.str
    subtitleText: builtins.str
    maxTitleNumOfLines: builtins.int
    maxSubtitleNumOfLines: builtins.int
    headerTitle: builtins.str
    overlayIconGlyph: global___ExtendedContentMessage.OverlayIconGlyph.ValueType
    overlayTitle: builtins.str
    overlayDescription: builtins.str
    sentWithMessageID: builtins.str
    messageText: builtins.str
    headerSubtitle: builtins.str
    xmaDataclass: builtins.str
    contentRef: builtins.str
    @property
    def associatedMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
    @property
    def ctas(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ExtendedContentMessage.CTA
    ]: ...
    @property
    def previews(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        waCommon.WACommon_pb2.SubProtocol
    ]: ...
    @property
    def favicon(self) -> waCommon.WACommon_pb2.SubProtocol: ...
    @property
    def headerImage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
    @property
    def mentionedJID(
        self,
    ) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.str
    ]: ...
    @property
    def commands(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        waCommon.WACommon_pb2.Command
    ]: ...
    def __init__(
        self,
        *,
        associatedMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
        targetType: global___ExtendedContentMessage.ExtendedContentType.ValueType
        | None = ...,
        targetUsername: builtins.str | None = ...,
        targetID: builtins.str | None = ...,
        targetExpiringAtSec: builtins.int | None = ...,
        xmaLayoutType: global___ExtendedContentMessage.XmaLayoutType.ValueType
        | None = ...,
        ctas: collections.abc.Iterable[global___ExtendedContentMessage.CTA]
        | None = ...,
        previews: collections.abc.Iterable[waCommon.WACommon_pb2.SubProtocol]
        | None = ...,
        titleText: builtins.str | None = ...,
        subtitleText: builtins.str | None = ...,
        maxTitleNumOfLines: builtins.int | None = ...,
        maxSubtitleNumOfLines: builtins.int | None = ...,
        favicon: waCommon.WACommon_pb2.SubProtocol | None = ...,
        headerImage: waCommon.WACommon_pb2.SubProtocol | None = ...,
        headerTitle: builtins.str | None = ...,
        overlayIconGlyph: global___ExtendedContentMessage.OverlayIconGlyph.ValueType
        | None = ...,
        overlayTitle: builtins.str | None = ...,
        overlayDescription: builtins.str | None = ...,
        sentWithMessageID: builtins.str | None = ...,
        messageText: builtins.str | None = ...,
        headerSubtitle: builtins.str | None = ...,
        xmaDataclass: builtins.str | None = ...,
        contentRef: builtins.str | None = ...,
        mentionedJID: collections.abc.Iterable[builtins.str] | None = ...,
        commands: collections.abc.Iterable[waCommon.WACommon_pb2.Command] | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "associatedMessage",
            b"associatedMessage",
            "contentRef",
            b"contentRef",
            "favicon",
            b"favicon",
            "headerImage",
            b"headerImage",
            "headerSubtitle",
            b"headerSubtitle",
            "headerTitle",
            b"headerTitle",
            "maxSubtitleNumOfLines",
            b"maxSubtitleNumOfLines",
            "maxTitleNumOfLines",
            b"maxTitleNumOfLines",
            "messageText",
            b"messageText",
            "overlayDescription",
            b"overlayDescription",
            "overlayIconGlyph",
            b"overlayIconGlyph",
            "overlayTitle",
            b"overlayTitle",
            "sentWithMessageID",
            b"sentWithMessageID",
            "subtitleText",
            b"subtitleText",
            "targetExpiringAtSec",
            b"targetExpiringAtSec",
            "targetID",
            b"targetID",
            "targetType",
            b"targetType",
            "targetUsername",
            b"targetUsername",
            "titleText",
            b"titleText",
            "xmaDataclass",
            b"xmaDataclass",
            "xmaLayoutType",
            b"xmaLayoutType",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "associatedMessage",
            b"associatedMessage",
            "commands",
            b"commands",
            "contentRef",
            b"contentRef",
            "ctas",
            b"ctas",
            "favicon",
            b"favicon",
            "headerImage",
            b"headerImage",
            "headerSubtitle",
            b"headerSubtitle",
            "headerTitle",
            b"headerTitle",
            "maxSubtitleNumOfLines",
            b"maxSubtitleNumOfLines",
            "maxTitleNumOfLines",
            b"maxTitleNumOfLines",
            "mentionedJID",
            b"mentionedJID",
            "messageText",
            b"messageText",
            "overlayDescription",
            b"overlayDescription",
            "overlayIconGlyph",
            b"overlayIconGlyph",
            "overlayTitle",
            b"overlayTitle",
            "previews",
            b"previews",
            "sentWithMessageID",
            b"sentWithMessageID",
            "subtitleText",
            b"subtitleText",
            "targetExpiringAtSec",
            b"targetExpiringAtSec",
            "targetID",
            b"targetID",
            "targetType",
            b"targetType",
            "targetUsername",
            b"targetUsername",
            "titleText",
            b"titleText",
            "xmaDataclass",
            b"xmaDataclass",
            "xmaLayoutType",
            b"xmaLayoutType",
        ],
    ) -> None: ...

global___ExtendedContentMessage = ExtendedContentMessage



import importlib.metadata
import os
from .utils.platform import generated_name
import requests
from pathlib import Path
from tqdm import tqdm


class UnsupportedPlatform(Exception):
    pass


def __download(url: str, fname: str, chunk_size=1024):
    resp = requests.get(url, stream=True)
    if resp.status_code != 200:
        resp.close()
        raise UnsupportedPlatform(generated_name())
    total = int(resp.headers.get("content-length", 0))
    with open(fname, "wb") as file, tqdm(
        desc=Path(fname).name,
        total=total,
        unit="iB",
        unit_scale=True,
        unit_divisor=1024,
    ) as bar:
        for data in resp.iter_content(chunk_size=chunk_size):
            size = file.write(data)
            bar.update(size)
        bar.n = total
    bar.close()


def download():
    version = importlib.metadata.version("neonize")
    __download(
        f"https://github.com/krypton-byte/neonize/releases/download/{version}/{generated_name()}",
        f"{os.path.dirname(__file__)}/{generated_name()}",
    )


if __name__ == "__main__":
    download()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waArmadilloBackupMessage/WAArmadilloBackupMessage.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n7waArmadilloBackupMessage/WAArmadilloBackupMessage.proto\x12\x18WAArmadilloBackupMessage"\xfc\x02\n\rBackupMessage\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.WAArmadilloBackupMessage.BackupMessage.Metadata\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x1a\x95\x02\n\x08Metadata\x12\x10\n\x08senderID\x18\x01 \x01(\t\x12\x11\n\tmessageID\x18\x02 \x01(\t\x12\x13\n\x0btimestampMS\x18\x03 \x01(\x03\x12[\n\x10\x66rankingMetadata\x18\x04 \x01(\x0b\x32\x41.WAArmadilloBackupMessage.BackupMessage.Metadata.FrankingMetadata\x12\x16\n\x0epayloadVersion\x18\x05 \x01(\x05\x12\x1b\n\x13\x66utureProofBehavior\x18\x06 \x01(\x05\x1a=\n\x10\x46rankingMetadata\x12\x13\n\x0b\x66rankingTag\x18\x03 \x01(\x0c\x12\x14\n\x0creportingTag\x18\x04 \x01(\x0c\x42\x34Z2go.mau.fi/whatsmeow/proto/waArmadilloBackupMessage'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waArmadilloBackupMessage.WAArmadilloBackupMessage_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z2go.mau.fi/whatsmeow/proto/waArmadilloBackupMessage"
    _globals["_BACKUPMESSAGE"]._serialized_start = 86
    _globals["_BACKUPMESSAGE"]._serialized_end = 466
    _globals["_BACKUPMESSAGE_METADATA"]._serialized_start = 189
    _globals["_BACKUPMESSAGE_METADATA"]._serialized_end = 466
    _globals["_BACKUPMESSAGE_METADATA_FRANKINGMETADATA"]._serialized_start = 405
    _globals["_BACKUPMESSAGE_METADATA_FRANKINGMETADATA"]._serialized_end = 466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waRoutingInfo/WAWebProtobufsRoutingInfo.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n-waRoutingInfo/WAWebProtobufsRoutingInfo.proto\x12\x19WAWebProtobufsRoutingInfo\"w\n\x0bRoutingInfo\x12\x10\n\x08regionID\x18\x01 \x03(\x05\x12\x11\n\tclusterID\x18\x02 \x03(\x05\x12\x0e\n\x06taskID\x18\x03 \x01(\x05\x12\r\n\x05\x64\x65\x62ug\x18\x04 \x01(\x08\x12\x0e\n\x06tcpBbr\x18\x05 \x01(\x08\x12\x14\n\x0ctcpKeepalive\x18\x06 \x01(\x08\x42)Z'go.mau.fi/whatsmeow/proto/waRoutingInfo"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waRoutingInfo.WAWebProtobufsRoutingInfo_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z'go.mau.fi/whatsmeow/proto/waRoutingInfo"
    _globals["_ROUTINGINFO"]._serialized_start = 76
    _globals["_ROUTINGINFO"]._serialized_end = 195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waWinUIApi/WAWinUIApi.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bwaWinUIApi/WAWinUIApi.proto\x12\nWAWinUIApi"\xa7\x02\n\x0fPositronMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\x02ID\x18\x04 \x01(\x0b\x32".WAWinUIApi.PositronMessage.MsgKey\x12\x0c\n\x04JSON\x18\x63 \x01(\t\x1a\x8b\x01\n\x06MsgKey\x12\x0e\n\x06\x66romMe\x18\x01 \x01(\x08\x12/\n\x06remote\x18\x02 \x01(\x0b\x32\x1f.WAWinUIApi.PositronMessage.WID\x12\n\n\x02ID\x18\x03 \x01(\t\x12\x34\n\x0bparticipant\x18\x04 \x01(\x0b\x32\x1f.WAWinUIApi.PositronMessage.WID\x1a\x19\n\x03WID\x12\x12\n\nserialized\x18\x01 \x01(\t"^\n\x0cPositronChat\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x13\n\x0bunreadCount\x18\x04 \x01(\x03\x12\x0c\n\x04JSON\x18\x63 \x01(\t"l\n\x0fPositronContact\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14isAddressBookContact\x18\x04 \x01(\x08\x12\x0c\n\x04JSON\x18\x63 \x01(\t"B\n\x15PositronGroupMetadata\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t"K\n\x19PositronGroupParticipants\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x14\n\x0cparticipants\x18\x02 \x03(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t"\x82\x01\n\x10PositronReaction\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x14\n\x0cparentMsgKey\x18\x02 \x01(\t\x12\x14\n\x0creactionText\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x15\n\rsenderUserJID\x18\x05 \x01(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t"\xf6\x02\n\x0cPositronData\x12\x32\n\ndataSource\x18\x01 \x01(\x0e\x32\x1e.WAWinUIApi.PositronDataSource\x12-\n\x08messages\x18\x02 \x03(\x0b\x32\x1b.WAWinUIApi.PositronMessage\x12\'\n\x05\x63hats\x18\x03 \x03(\x0b\x32\x18.WAWinUIApi.PositronChat\x12-\n\x08\x63ontacts\x18\x04 \x03(\x0b\x32\x1b.WAWinUIApi.PositronContact\x12\x38\n\rgroupMetadata\x18\x05 \x03(\x0b\x32!.WAWinUIApi.PositronGroupMetadata\x12@\n\x11groupParticipants\x18\x06 \x03(\x0b\x32%.WAWinUIApi.PositronGroupParticipants\x12/\n\treactions\x18\x07 \x03(\x0b\x32\x1c.WAWinUIApi.PositronReaction*v\n\x12PositronDataSource\x12\x0c\n\x08MESSAGES\x10\x01\x12\t\n\x05\x43HATS\x10\x02\x12\x0c\n\x08\x43ONTACTS\x10\x03\x12\x12\n\x0eGROUP_METADATA\x10\x04\x12\x16\n\x12GROUP_PARTICIPANTS\x10\x05\x12\r\n\tREACTIONS\x10\x06\x42&Z$go.mau.fi/whatsmeow/proto/waWinUIApi'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waWinUIApi.WAWinUIApi_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z$go.mau.fi/whatsmeow/proto/waWinUIApi"
    _globals["_POSITRONDATASOURCE"]._serialized_start = 1202
    _globals["_POSITRONDATASOURCE"]._serialized_end = 1320
    _globals["_POSITRONMESSAGE"]._serialized_start = 44
    _globals["_POSITRONMESSAGE"]._serialized_end = 339
    _globals["_POSITRONMESSAGE_MSGKEY"]._serialized_start = 173
    _globals["_POSITRONMESSAGE_MSGKEY"]._serialized_end = 312
    _globals["_POSITRONMESSAGE_WID"]._serialized_start = 314
    _globals["_POSITRONMESSAGE_WID"]._serialized_end = 339
    _globals["_POSITRONCHAT"]._serialized_start = 341
    _globals["_POSITRONCHAT"]._serialized_end = 435
    _globals["_POSITRONCONTACT"]._serialized_start = 437
    _globals["_POSITRONCONTACT"]._serialized_end = 545
    _globals["_POSITRONGROUPMETADATA"]._serialized_start = 547
    _globals["_POSITRONGROUPMETADATA"]._serialized_end = 613
    _globals["_POSITRONGROUPPARTICIPANTS"]._serialized_start = 615
    _globals["_POSITRONGROUPPARTICIPANTS"]._serialized_end = 690
    _globals["_POSITRONREACTION"]._serialized_start = 693
    _globals["_POSITRONREACTION"]._serialized_end = 823
    _globals["_POSITRONDATA"]._serialized_start = 826
    _globals["_POSITRONDATA"]._serialized_end = 1200
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waCommon/WACommon.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17waCommon/WACommon.proto\x12\x08WACommon"P\n\nMessageKey\x12\x11\n\tremoteJID\x18\x01 \x01(\t\x12\x0e\n\x06\x66romMe\x18\x02 \x01(\x08\x12\n\n\x02ID\x18\x03 \x01(\t\x12\x13\n\x0bparticipant\x18\x04 \x01(\t"\xb7\x01\n\x07\x43ommand\x12\x32\n\x0b\x63ommandType\x18\x01 \x01(\x0e\x32\x1d.WACommon.Command.CommandType\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x0e\n\x06length\x18\x03 \x01(\r\x12\x17\n\x0fvalidationToken\x18\x04 \x01(\t"?\n\x0b\x43ommandType\x12\x0c\n\x08\x45VERYONE\x10\x01\x12\n\n\x06SILENT\x10\x02\x12\x06\n\x02\x41I\x10\x03\x12\x0e\n\nAI_IMAGINE\x10\x04"V\n\x0bMessageText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x14\n\x0cmentionedJID\x18\x02 \x03(\t\x12#\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x11.WACommon.Command"/\n\x0bSubProtocol\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\x05*F\n\x13\x46utureProofBehavior\x12\x0f\n\x0bPLACEHOLDER\x10\x00\x12\x12\n\x0eNO_PLACEHOLDER\x10\x01\x12\n\n\x06IGNORE\x10\x02\x42$Z"go.mau.fi/whatsmeow/proto/waCommon'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "waCommon.WACommon_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b'Z"go.mau.fi/whatsmeow/proto/waCommon'
    _globals["_FUTUREPROOFBEHAVIOR"]._serialized_start = 442
    _globals["_FUTUREPROOFBEHAVIOR"]._serialized_end = 512
    _globals["_MESSAGEKEY"]._serialized_start = 37
    _globals["_MESSAGEKEY"]._serialized_end = 117
    _globals["_COMMAND"]._serialized_start = 120
    _globals["_COMMAND"]._serialized_end = 303
    _globals["_COMMAND_COMMANDTYPE"]._serialized_start = 240
    _globals["_COMMAND_COMMANDTYPE"]._serialized_end = 303
    _globals["_MESSAGETEXT"]._serialized_start = 305
    _globals["_MESSAGETEXT"]._serialized_end = 391
    _globals["_SUBPROTOCOL"]._serialized_start = 393
    _globals["_SUBPROTOCOL"]._serialized_end = 440
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waFingerprint/WAFingerprint.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!waFingerprint/WAFingerprint.proto\x12\rWAFingerprint"\x9e\x01\n\x0f\x46ingerprintData\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x14\n\x0cpnIdentifier\x18\x02 \x01(\x0c\x12\x15\n\rlidIdentifier\x18\x03 \x01(\x0c\x12\x1a\n\x12usernameIdentifier\x18\x04 \x01(\x0c\x12/\n\x0bhostedState\x18\x05 \x01(\x0e\x32\x1a.WAFingerprint.HostedState"\x9b\x01\n\x13\x43ombinedFingerprint\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x38\n\x10localFingerprint\x18\x02 \x01(\x0b\x32\x1e.WAFingerprint.FingerprintData\x12\x39\n\x11remoteFingerprint\x18\x03 \x01(\x0b\x32\x1e.WAFingerprint.FingerprintData*#\n\x0bHostedState\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\n\n\x06HOSTED\x10\x01\x42)Z\'go.mau.fi/whatsmeow/proto/waFingerprint'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waFingerprint.WAFingerprint_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z'go.mau.fi/whatsmeow/proto/waFingerprint"
    _globals["_HOSTEDSTATE"]._serialized_start = 371
    _globals["_HOSTEDSTATE"]._serialized_end = 406
    _globals["_FINGERPRINTDATA"]._serialized_start = 53
    _globals["_FINGERPRINTDATA"]._serialized_end = 211
    _globals["_COMBINEDFINGERPRINT"]._serialized_start = 214
    _globals["_COMBINEDFINGERPRINT"]._serialized_end = 369
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waChatLockSettings/WAProtobufsChatLockSettings.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waUserPassword import (
    WAProtobufsUserPassword_pb2 as waUserPassword_dot_WAProtobufsUserPassword__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n4waChatLockSettings/WAProtobufsChatLockSettings.proto\x12\x1bWAProtobufsChatLockSettings\x1a,waUserPassword/WAProtobufsUserPassword.proto"f\n\x10\x43hatLockSettings\x12\x17\n\x0fhideLockedChats\x18\x01 \x01(\x08\x12\x39\n\nsecretCode\x18\x02 \x01(\x0b\x32%.WAProtobufsUserPassword.UserPasswordB.Z,go.mau.fi/whatsmeow/proto/waChatLockSettings'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waChatLockSettings.WAProtobufsChatLockSettings_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z,go.mau.fi/whatsmeow/proto/waChatLockSettings"
    _globals["_CHATLOCKSETTINGS"]._serialized_start = 131
    _globals["_CHATLOCKSETTINGS"]._serialized_end = 233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waQuickPromotionSurfaces/WAWebProtobufsQuickPromotionSurfaces.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\nCwaQuickPromotionSurfaces/WAWebProtobufsQuickPromotionSurfaces.proto\x12$WAWebProtobufsQuickPromotionSurfaces"\xe4\x05\n\x02QP\x1a\xe1\x01\n\x0c\x46ilterClause\x12G\n\nclauseType\x18\x01 \x02(\x0e\x32\x33.WAWebProtobufsQuickPromotionSurfaces.QP.ClauseType\x12\x46\n\x07\x63lauses\x18\x02 \x03(\x0b\x32\x35.WAWebProtobufsQuickPromotionSurfaces.QP.FilterClause\x12@\n\x07\x66ilters\x18\x03 \x03(\x0b\x32/.WAWebProtobufsQuickPromotionSurfaces.QP.Filter\x1a\xa3\x02\n\x06\x46ilter\x12\x12\n\nfilterName\x18\x01 \x02(\t\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.WAWebProtobufsQuickPromotionSurfaces.QP.FilterParameters\x12K\n\x0c\x66ilterResult\x18\x03 \x01(\x0e\x32\x35.WAWebProtobufsQuickPromotionSurfaces.QP.FilterResult\x12i\n\x18\x63lientNotSupportedConfig\x18\x04 \x02(\x0e\x32G.WAWebProtobufsQuickPromotionSurfaces.QP.FilterClientNotSupportedConfig\x1a.\n\x10\x46ilterParameters\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"0\n\x0c\x46ilterResult\x12\x08\n\x04TRUE\x10\x01\x12\t\n\x05\x46\x41LSE\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x03"J\n\x1e\x46ilterClientNotSupportedConfig\x12\x13\n\x0fPASS_BY_DEFAULT\x10\x01\x12\x13\n\x0f\x46\x41IL_BY_DEFAULT\x10\x02"&\n\nClauseType\x12\x07\n\x03\x41ND\x10\x01\x12\x06\n\x02OR\x10\x02\x12\x07\n\x03NOR\x10\x03\x42\x34Z2go.mau.fi/whatsmeow/proto/waQuickPromotionSurfaces'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR,
    "waQuickPromotionSurfaces.WAWebProtobufsQuickPromotionSurfaces_pb2",
    _globals,
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z2go.mau.fi/whatsmeow/proto/waQuickPromotionSurfaces"
    _globals["_QP"]._serialized_start = 110
    _globals["_QP"]._serialized_end = 850
    _globals["_QP_FILTERCLAUSE"]._serialized_start = 117
    _globals["_QP_FILTERCLAUSE"]._serialized_end = 342
    _globals["_QP_FILTER"]._serialized_start = 345
    _globals["_QP_FILTER"]._serialized_end = 636
    _globals["_QP_FILTERPARAMETERS"]._serialized_start = 638
    _globals["_QP_FILTERPARAMETERS"]._serialized_end = 684
    _globals["_QP_FILTERRESULT"]._serialized_start = 686
    _globals["_QP_FILTERRESULT"]._serialized_end = 734
    _globals["_QP_FILTERCLIENTNOTSUPPORTEDCONFIG"]._serialized_start = 736
    _globals["_QP_FILTERCLIENTNOTSUPPORTEDCONFIG"]._serialized_end = 810
    _globals["_QP_CLAUSETYPE"]._serialized_start = 812
    _globals["_QP_CLAUSETYPE"]._serialized_end = 850
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class QP(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _FilterResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FilterResultEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            QP._FilterResult.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRUE: QP._FilterResult.ValueType  # 1
        FALSE: QP._FilterResult.ValueType  # 2
        UNKNOWN: QP._FilterResult.ValueType  # 3

    class FilterResult(_FilterResult, metaclass=_FilterResultEnumTypeWrapper): ...
    TRUE: QP.FilterResult.ValueType  # 1
    FALSE: QP.FilterResult.ValueType  # 2
    UNKNOWN: QP.FilterResult.ValueType  # 3

    class _FilterClientNotSupportedConfig:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FilterClientNotSupportedConfigEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            QP._FilterClientNotSupportedConfig.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PASS_BY_DEFAULT: QP._FilterClientNotSupportedConfig.ValueType  # 1
        FAIL_BY_DEFAULT: QP._FilterClientNotSupportedConfig.ValueType  # 2

    class FilterClientNotSupportedConfig(
        _FilterClientNotSupportedConfig,
        metaclass=_FilterClientNotSupportedConfigEnumTypeWrapper,
    ): ...
    PASS_BY_DEFAULT: QP.FilterClientNotSupportedConfig.ValueType  # 1
    FAIL_BY_DEFAULT: QP.FilterClientNotSupportedConfig.ValueType  # 2

    class _ClauseType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ClauseTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            QP._ClauseType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AND: QP._ClauseType.ValueType  # 1
        OR: QP._ClauseType.ValueType  # 2
        NOR: QP._ClauseType.ValueType  # 3

    class ClauseType(_ClauseType, metaclass=_ClauseTypeEnumTypeWrapper): ...
    AND: QP.ClauseType.ValueType  # 1
    OR: QP.ClauseType.ValueType  # 2
    NOR: QP.ClauseType.ValueType  # 3

    @typing.final
    class FilterClause(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CLAUSETYPE_FIELD_NUMBER: builtins.int
        CLAUSES_FIELD_NUMBER: builtins.int
        FILTERS_FIELD_NUMBER: builtins.int
        clauseType: global___QP.ClauseType.ValueType
        @property
        def clauses(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___QP.FilterClause
        ]: ...
        @property
        def filters(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___QP.Filter
        ]: ...
        def __init__(
            self,
            *,
            clauseType: global___QP.ClauseType.ValueType | None = ...,
            clauses: collections.abc.Iterable[global___QP.FilterClause] | None = ...,
            filters: collections.abc.Iterable[global___QP.Filter] | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["clauseType", b"clauseType"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "clauseType",
                b"clauseType",
                "clauses",
                b"clauses",
                "filters",
                b"filters",
            ],
        ) -> None: ...

    @typing.final
    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILTERNAME_FIELD_NUMBER: builtins.int
        PARAMETERS_FIELD_NUMBER: builtins.int
        FILTERRESULT_FIELD_NUMBER: builtins.int
        CLIENTNOTSUPPORTEDCONFIG_FIELD_NUMBER: builtins.int
        filterName: builtins.str
        filterResult: global___QP.FilterResult.ValueType
        clientNotSupportedConfig: global___QP.FilterClientNotSupportedConfig.ValueType
        @property
        def parameters(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___QP.FilterParameters
        ]: ...
        def __init__(
            self,
            *,
            filterName: builtins.str | None = ...,
            parameters: collections.abc.Iterable[global___QP.FilterParameters]
            | None = ...,
            filterResult: global___QP.FilterResult.ValueType | None = ...,
            clientNotSupportedConfig: global___QP.FilterClientNotSupportedConfig.ValueType
            | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "clientNotSupportedConfig",
                b"clientNotSupportedConfig",
                "filterName",
                b"filterName",
                "filterResult",
                b"filterResult",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "clientNotSupportedConfig",
                b"clientNotSupportedConfig",
                "filterName",
                b"filterName",
                "filterResult",
                b"filterResult",
                "parameters",
                b"parameters",
            ],
        ) -> None: ...

    @typing.final
    class FilterParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str | None = ...,
            value: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["key", b"key", "value", b"value"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["key", b"key", "value", b"value"]
        ) -> None: ...

    def __init__(
        self,
    ) -> None: ...

global___QP = QP



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waEphemeral/WAWebProtobufsEphemeral.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n)waEphemeral/WAWebProtobufsEphemeral.proto\x12\x17WAWebProtobufsEphemeral\"7\n\x10\x45phemeralSetting\x12\x10\n\x08\x64uration\x18\x01 \x01(\x0f\x12\x11\n\ttimestamp\x18\x02 \x01(\x10\x42'Z%go.mau.fi/whatsmeow/proto/waEphemeral"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waEphemeral.WAWebProtobufsEphemeral_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z%go.mau.fi/whatsmeow/proto/waEphemeral"
    _globals["_EPHEMERALSETTING"]._serialized_start = 70
    _globals["_EPHEMERALSETTING"]._serialized_end = 125
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waReporting/WAWebProtobufsReporting.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)waReporting/WAWebProtobufsReporting.proto\x12\x17WAWebProtobufsReporting"d\n\nReportable\x12\x12\n\nminVersion\x18\x01 \x01(\r\x12\x12\n\nmaxVersion\x18\x02 \x01(\r\x12\x1f\n\x17notReportableMinVersion\x18\x03 \x01(\r\x12\r\n\x05never\x18\x04 \x01(\x08"\xa2\x01\n\x06\x43onfig\x12\x39\n\x05\x66ield\x18\x01 \x03(\x0b\x32*.WAWebProtobufsReporting.Config.FieldEntry\x12\x0f\n\x07version\x18\x02 \x01(\r\x1aL\n\nFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.WAWebProtobufsReporting.Field:\x02\x38\x01"\xf4\x01\n\x05\x46ield\x12\x12\n\nminVersion\x18\x01 \x01(\r\x12\x12\n\nmaxVersion\x18\x02 \x01(\r\x12\x1f\n\x17notReportableMinVersion\x18\x03 \x01(\r\x12\x11\n\tisMessage\x18\x04 \x01(\x08\x12>\n\x08subfield\x18\x05 \x03(\x0b\x32,.WAWebProtobufsReporting.Field.SubfieldEntry\x1aO\n\rSubfieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.WAWebProtobufsReporting.Field:\x02\x38\x01\x42\'Z%go.mau.fi/whatsmeow/proto/waReportingb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waReporting.WAWebProtobufsReporting_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z%go.mau.fi/whatsmeow/proto/waReporting"
    _globals["_CONFIG_FIELDENTRY"]._options = None
    _globals["_CONFIG_FIELDENTRY"]._serialized_options = b"8\001"
    _globals["_FIELD_SUBFIELDENTRY"]._options = None
    _globals["_FIELD_SUBFIELDENTRY"]._serialized_options = b"8\001"
    _globals["_REPORTABLE"]._serialized_start = 70
    _globals["_REPORTABLE"]._serialized_end = 170
    _globals["_CONFIG"]._serialized_start = 173
    _globals["_CONFIG"]._serialized_end = 335
    _globals["_CONFIG_FIELDENTRY"]._serialized_start = 259
    _globals["_CONFIG_FIELDENTRY"]._serialized_end = 335
    _globals["_FIELD"]._serialized_start = 338
    _globals["_FIELD"]._serialized_end = 582
    _globals["_FIELD_SUBFIELDENTRY"]._serialized_start = 503
    _globals["_FIELD_SUBFIELDENTRY"]._serialized_end = 582
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MessageApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _ThreadType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ThreadTypeEnumTypeWrapper(
            google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
                MessageApplication.Metadata._ThreadType.ValueType
            ],
            builtins.type,
        ):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            DEFAULT: MessageApplication.Metadata._ThreadType.ValueType  # 0
            VANISH_MODE: MessageApplication.Metadata._ThreadType.ValueType  # 1
            DISAPPEARING_MESSAGES: (
                MessageApplication.Metadata._ThreadType.ValueType
            )  # 2

        class ThreadType(_ThreadType, metaclass=_ThreadTypeEnumTypeWrapper): ...
        DEFAULT: MessageApplication.Metadata.ThreadType.ValueType  # 0
        VANISH_MODE: MessageApplication.Metadata.ThreadType.ValueType  # 1
        DISAPPEARING_MESSAGES: MessageApplication.Metadata.ThreadType.ValueType  # 2

        @typing.final
        class QuotedMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            STANZAID_FIELD_NUMBER: builtins.int
            REMOTEJID_FIELD_NUMBER: builtins.int
            PARTICIPANT_FIELD_NUMBER: builtins.int
            PAYLOAD_FIELD_NUMBER: builtins.int
            stanzaID: builtins.str
            remoteJID: builtins.str
            participant: builtins.str
            @property
            def payload(self) -> global___MessageApplication.Payload: ...
            def __init__(
                self,
                *,
                stanzaID: builtins.str | None = ...,
                remoteJID: builtins.str | None = ...,
                participant: builtins.str | None = ...,
                payload: global___MessageApplication.Payload | None = ...,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing.Literal[
                    "participant",
                    b"participant",
                    "payload",
                    b"payload",
                    "remoteJID",
                    b"remoteJID",
                    "stanzaID",
                    b"stanzaID",
                ],
            ) -> builtins.bool: ...
            def ClearField(
                self,
                field_name: typing.Literal[
                    "participant",
                    b"participant",
                    "payload",
                    b"payload",
                    "remoteJID",
                    b"remoteJID",
                    "stanzaID",
                    b"stanzaID",
                ],
            ) -> None: ...

        @typing.final
        class EphemeralSettingMap(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            CHATJID_FIELD_NUMBER: builtins.int
            EPHEMERALSETTING_FIELD_NUMBER: builtins.int
            chatJID: builtins.str
            @property
            def ephemeralSetting(
                self,
            ) -> global___MessageApplication.EphemeralSetting: ...
            def __init__(
                self,
                *,
                chatJID: builtins.str | None = ...,
                ephemeralSetting: global___MessageApplication.EphemeralSetting
                | None = ...,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing.Literal[
                    "chatJID", b"chatJID", "ephemeralSetting", b"ephemeralSetting"
                ],
            ) -> builtins.bool: ...
            def ClearField(
                self,
                field_name: typing.Literal[
                    "chatJID", b"chatJID", "ephemeralSetting", b"ephemeralSetting"
                ],
            ) -> None: ...

        CHATEPHEMERALSETTING_FIELD_NUMBER: builtins.int
        EPHEMERALSETTINGLIST_FIELD_NUMBER: builtins.int
        EPHEMERALSHAREDSECRET_FIELD_NUMBER: builtins.int
        FORWARDINGSCORE_FIELD_NUMBER: builtins.int
        ISFORWARDED_FIELD_NUMBER: builtins.int
        BUSINESSMETADATA_FIELD_NUMBER: builtins.int
        FRANKINGKEY_FIELD_NUMBER: builtins.int
        FRANKINGVERSION_FIELD_NUMBER: builtins.int
        QUOTEDMESSAGE_FIELD_NUMBER: builtins.int
        THREADTYPE_FIELD_NUMBER: builtins.int
        READONLYMETADATADATACLASS_FIELD_NUMBER: builtins.int
        GROUPID_FIELD_NUMBER: builtins.int
        GROUPSIZE_FIELD_NUMBER: builtins.int
        GROUPINDEX_FIELD_NUMBER: builtins.int
        BOTRESPONSEID_FIELD_NUMBER: builtins.int
        COLLAPSIBLEID_FIELD_NUMBER: builtins.int
        SECONDARYOTID_FIELD_NUMBER: builtins.int
        ephemeralSharedSecret: builtins.bytes
        forwardingScore: builtins.int
        isForwarded: builtins.bool
        frankingKey: builtins.bytes
        frankingVersion: builtins.int
        threadType: global___MessageApplication.Metadata.ThreadType.ValueType
        readonlyMetadataDataclass: builtins.str
        groupID: builtins.str
        groupSize: builtins.int
        groupIndex: builtins.int
        botResponseID: builtins.str
        collapsibleID: builtins.str
        secondaryOtid: builtins.str
        @property
        def chatEphemeralSetting(
            self,
        ) -> global___MessageApplication.EphemeralSetting: ...
        @property
        def ephemeralSettingList(
            self,
        ) -> global___MessageApplication.Metadata.EphemeralSettingMap: ...
        @property
        def businessMetadata(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def quotedMessage(
            self,
        ) -> global___MessageApplication.Metadata.QuotedMessage: ...
        def __init__(
            self,
            *,
            chatEphemeralSetting: global___MessageApplication.EphemeralSetting
            | None = ...,
            ephemeralSettingList: global___MessageApplication.Metadata.EphemeralSettingMap
            | None = ...,
            ephemeralSharedSecret: builtins.bytes | None = ...,
            forwardingScore: builtins.int | None = ...,
            isForwarded: builtins.bool | None = ...,
            businessMetadata: waCommon.WACommon_pb2.SubProtocol | None = ...,
            frankingKey: builtins.bytes | None = ...,
            frankingVersion: builtins.int | None = ...,
            quotedMessage: global___MessageApplication.Metadata.QuotedMessage
            | None = ...,
            threadType: global___MessageApplication.Metadata.ThreadType.ValueType
            | None = ...,
            readonlyMetadataDataclass: builtins.str | None = ...,
            groupID: builtins.str | None = ...,
            groupSize: builtins.int | None = ...,
            groupIndex: builtins.int | None = ...,
            botResponseID: builtins.str | None = ...,
            collapsibleID: builtins.str | None = ...,
            secondaryOtid: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "botResponseID",
                b"botResponseID",
                "businessMetadata",
                b"businessMetadata",
                "chatEphemeralSetting",
                b"chatEphemeralSetting",
                "collapsibleID",
                b"collapsibleID",
                "ephemeral",
                b"ephemeral",
                "ephemeralSettingList",
                b"ephemeralSettingList",
                "ephemeralSharedSecret",
                b"ephemeralSharedSecret",
                "forwardingScore",
                b"forwardingScore",
                "frankingKey",
                b"frankingKey",
                "frankingVersion",
                b"frankingVersion",
                "groupID",
                b"groupID",
                "groupIndex",
                b"groupIndex",
                "groupSize",
                b"groupSize",
                "isForwarded",
                b"isForwarded",
                "quotedMessage",
                b"quotedMessage",
                "readonlyMetadataDataclass",
                b"readonlyMetadataDataclass",
                "secondaryOtid",
                b"secondaryOtid",
                "threadType",
                b"threadType",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "botResponseID",
                b"botResponseID",
                "businessMetadata",
                b"businessMetadata",
                "chatEphemeralSetting",
                b"chatEphemeralSetting",
                "collapsibleID",
                b"collapsibleID",
                "ephemeral",
                b"ephemeral",
                "ephemeralSettingList",
                b"ephemeralSettingList",
                "ephemeralSharedSecret",
                b"ephemeralSharedSecret",
                "forwardingScore",
                b"forwardingScore",
                "frankingKey",
                b"frankingKey",
                "frankingVersion",
                b"frankingVersion",
                "groupID",
                b"groupID",
                "groupIndex",
                b"groupIndex",
                "groupSize",
                b"groupSize",
                "isForwarded",
                b"isForwarded",
                "quotedMessage",
                b"quotedMessage",
                "readonlyMetadataDataclass",
                b"readonlyMetadataDataclass",
                "secondaryOtid",
                b"secondaryOtid",
                "threadType",
                b"threadType",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["ephemeral", b"ephemeral"]
        ) -> (
            typing.Literal[
                "chatEphemeralSetting", "ephemeralSettingList", "ephemeralSharedSecret"
            ]
            | None
        ): ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CORECONTENT_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SUBPROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def coreContent(self) -> global___MessageApplication.Content: ...
        @property
        def signal(self) -> global___MessageApplication.Signal: ...
        @property
        def applicationData(self) -> global___MessageApplication.ApplicationData: ...
        @property
        def subProtocol(self) -> global___MessageApplication.SubProtocolPayload: ...
        def __init__(
            self,
            *,
            coreContent: global___MessageApplication.Content | None = ...,
            signal: global___MessageApplication.Signal | None = ...,
            applicationData: global___MessageApplication.ApplicationData | None = ...,
            subProtocol: global___MessageApplication.SubProtocolPayload | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "applicationData",
                b"applicationData",
                "content",
                b"content",
                "coreContent",
                b"coreContent",
                "signal",
                b"signal",
                "subProtocol",
                b"subProtocol",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "applicationData",
                b"applicationData",
                "content",
                b"content",
                "coreContent",
                b"coreContent",
                "signal",
                b"signal",
                "subProtocol",
                b"subProtocol",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["content", b"content"]
        ) -> (
            typing.Literal["coreContent", "signal", "applicationData", "subProtocol"]
            | None
        ): ...

    @typing.final
    class SubProtocolPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONSUMERMESSAGE_FIELD_NUMBER: builtins.int
        BUSINESSMESSAGE_FIELD_NUMBER: builtins.int
        PAYMENTMESSAGE_FIELD_NUMBER: builtins.int
        MULTIDEVICE_FIELD_NUMBER: builtins.int
        VOIP_FIELD_NUMBER: builtins.int
        ARMADILLO_FIELD_NUMBER: builtins.int
        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        @property
        def consumerMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def businessMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def paymentMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def multiDevice(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def voip(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def armadillo(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            consumerMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
            businessMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
            paymentMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
            multiDevice: waCommon.WACommon_pb2.SubProtocol | None = ...,
            voip: waCommon.WACommon_pb2.SubProtocol | None = ...,
            armadillo: waCommon.WACommon_pb2.SubProtocol | None = ...,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
            | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "armadillo",
                b"armadillo",
                "businessMessage",
                b"businessMessage",
                "consumerMessage",
                b"consumerMessage",
                "futureProof",
                b"futureProof",
                "multiDevice",
                b"multiDevice",
                "paymentMessage",
                b"paymentMessage",
                "subProtocol",
                b"subProtocol",
                "voip",
                b"voip",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "armadillo",
                b"armadillo",
                "businessMessage",
                b"businessMessage",
                "consumerMessage",
                b"consumerMessage",
                "futureProof",
                b"futureProof",
                "multiDevice",
                b"multiDevice",
                "paymentMessage",
                b"paymentMessage",
                "subProtocol",
                b"subProtocol",
                "voip",
                b"voip",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["subProtocol", b"subProtocol"]
        ) -> (
            typing.Literal[
                "consumerMessage",
                "businessMessage",
                "paymentMessage",
                "multiDevice",
                "voip",
                "armadillo",
            ]
            | None
        ): ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Content(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class EphemeralSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EPHEMERALEXPIRATION_FIELD_NUMBER: builtins.int
        EPHEMERALSETTINGTIMESTAMP_FIELD_NUMBER: builtins.int
        ISEPHEMERALSETTINGRESET_FIELD_NUMBER: builtins.int
        ephemeralExpiration: builtins.int
        ephemeralSettingTimestamp: builtins.int
        isEphemeralSettingReset: builtins.bool
        def __init__(
            self,
            *,
            ephemeralExpiration: builtins.int | None = ...,
            ephemeralSettingTimestamp: builtins.int | None = ...,
            isEphemeralSettingReset: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "ephemeralExpiration",
                b"ephemeralExpiration",
                "ephemeralSettingTimestamp",
                b"ephemeralSettingTimestamp",
                "isEphemeralSettingReset",
                b"isEphemeralSettingReset",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "ephemeralExpiration",
                b"ephemeralExpiration",
                "ephemeralSettingTimestamp",
                b"ephemeralSettingTimestamp",
                "isEphemeralSettingReset",
                b"isEphemeralSettingReset",
            ],
        ) -> None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___MessageApplication.Payload: ...
    @property
    def metadata(self) -> global___MessageApplication.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___MessageApplication.Payload | None = ...,
        metadata: global___MessageApplication.Metadata | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]
    ) -> None: ...

global___MessageApplication = MessageApplication



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waArmadilloICDC/WAArmadilloICDC.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%waArmadilloICDC/WAArmadilloICDC.proto\x12\x0fWAArmadilloICDC"_\n\x10ICDCIdentityList\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x64\x65vices\x18\x03 \x03(\x0c\x12\x1a\n\x12signingDeviceIndex\x18\x04 \x01(\x05"<\n\x16SignedICDCIdentityList\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x42+Z)go.mau.fi/whatsmeow/proto/waArmadilloICDC'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waArmadilloICDC.WAArmadilloICDC_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z)go.mau.fi/whatsmeow/proto/waArmadilloICDC"
    _globals["_ICDCIDENTITYLIST"]._serialized_start = 58
    _globals["_ICDCIDENTITYLIST"]._serialized_end = 153
    _globals["_SIGNEDICDCIDENTITYLIST"]._serialized_start = 155
    _globals["_SIGNEDICDCIDENTITYLIST"]._serialized_end = 215
# @@protoc_insertion_point(module_scope)
